<?php

declare(strict_types=1);

namespace Drupal\graphql\Plugin\GraphQL\DataProducer\Entity;

use Drupal\Core\Entity\EntityInterface;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;

/**
 * Returns the ID of an entity.
 *
 * @DataProducer(
 *   id = "entity_id",
 *   name = @Translation("Entity identifier"),
 *   description = @Translation("Returns the entity identifier."),
 *   produces = @ContextDefinition("string",
 *     label = @Translation("Identifier")
 *   ),
 *   consumes = {
 *     "entity" = @ContextDefinition("entity",
 *       label = @Translation("Entity")
 *     )
 *   }
 * )
 */
class EntityId extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @return int|string|null
   *   The entity ID as integer or string, null if the entity has no ID yet.
   */
  public function resolve(EntityInterface $entity): int|string|null {
    return $entity->id();
  }

}
