<?php

declare(strict_types=1);

namespace Drupal\graphql\Plugin\GraphQL\DataProducer\Entity;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;

/**
 * Returns the URL of an entity.
 *
 * @DataProducer(
 *   id = "entity_url",
 *   name = @Translation("Entity url"),
 *   description = @Translation("Returns the entity's url."),
 *   produces = @ContextDefinition("any",
 *     label = @Translation("Url")
 *   ),
 *   consumes = {
 *     "entity" = @ContextDefinition("entity",
 *       label = @Translation("Entity")
 *     ),
 *     "rel" = @ContextDefinition("string",
 *       label = @Translation("Relationship type"),
 *       description = @Translation("The relationship type, e.g. canonical"),
 *       required = FALSE
 *     ),
 *     "options" = @ContextDefinition("any",
 *       label = @Translation("URL Options"),
 *       description = @Translation("Options to pass to the toUrl call"),
 *       required = FALSE
 *     )
 *   }
 * )
 */
class EntityUrl extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity to create a canonical URL for.
   * @param string|null $rel
   *   The link relation type, for example: canonical or edit-form.
   * @param array|null $options
   *   The options to provided to the URL generator.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   *   When the entity cannot provide a URL.
   *
   * @return \Drupal\Core\Url
   *   The URL object for the entity with the given relation.
   */
  public function resolve(EntityInterface $entity, ?string $rel, ?array $options): Url {
    return $entity->toUrl($rel ?? 'canonical', $options ?? []);
  }

}
